# NCSU Faker

Faker providers for NCSU test seed data

## Usage

With fzaninotto/Faker:

```
$faker = new Faker\Generator();
$faker->addProvider(new \NCSUFaker\CalendarProvider($faker));
```


## Installation

`composer require mcamiano/ncsu-faker`

## Providers

### CalendarProvider

Enumerations of various entities used to structure schedules, calendar periods, and events.

strm    // four digit Semester TeRM code

### LocationProvider

NCSU building location provider

location // building location. array includes building abbreviation, building name, building nicknames, street address, street name, state, and zip code

## OuProvider

Organizational unit code provider

unit    // unit name ; pass ou code for direct translation to name

unitOuc // 2-digit ou code for unit ; pass ou name for direct translation to code

department // department name ; pass ou name to limit to one unit

departmentOuc // 6-digit ou code for department ; pass ou name to limit to one unit

## NcsuLoremIpsumProvider

dogOfWisdomIpsum    // Lorem ipsum wisdom, dog style

trololoIpsum        // Lorem ipsum, from Trololo song lyrics

jasonIpsum          // like Lorem ipsum, but in a meeting

superJasonIpsum     // like Lorem ipsum, but in a meeting, on steroids

### Miscellaneous

naturalNumber  // non-zero whole number

## Example

```php
<?php

include "vendor/autoload.php";

$faker = new Faker\Generator();
$faker->addProvider(new \NCSUFaker\NcsuLoremIpsumProvider($faker));
$faker->addProvider(new \NCSUFaker\OuProvider($faker));

echo "Dog of Wisdom Ipsum: ".$faker->dogOfWisdomIpsum(rand(1,20)).PHP_EOL;
echo "Trololo Ipsum: ".$faker->trololoIpsum(rand(1,20)).PHP_EOL;
echo "Jason Ipsum: ".$faker->jasonIpsum(rand(1,20)).PHP_EOL;

echo "Unit: ".($unit=$faker->unit()).PHP_EOL;
echo "Department: ".$faker->department($unit).PHP_EOL;
echo "Department Ouc: ".$faker->departmentOuc($unit).PHP_EOL;
```
